@@ -57,6 +57,7 @@ class ClientHeart:
                 now_time = time.time()
                 all_distribute_done = True  # 是否任务分发完毕（只有 master 会分发）
                 all_client_is_waiting = True  # 是否所有客户端都无任务处理
+
                 heartbeat = redis_conn.hgetall(settings.REDIS_KEY_HEARTBEAT)
                 for client_name, detail in heartbeat.items():
                     client_name = client_name.decode()
@@ -90,8 +91,8 @@ class ClientHeart:
                             all_distribute_done = False
                         logger.debug(f"心跳正常：{client_name}")
 
-                # 如果所有客户端都无任务进行，并且任务分发完毕，则结束
-                if heartbeat and all_client_is_waiting and all_distribute_done:
+                # 如果所有客户端都无任务进行、任务分发完毕、item 队列为空，则结束
+                if heartbeat and all_client_is_waiting and all_distribute_done and self.spider.queue_item.empty():
                     logger.debug("所有客户端都已挂起，即将停止")
                     self.stop_all_client()
                     break
@@ -112,8 +113,8 @@ class ClientHeart:
             # 检测是否分发完毕
             heart = {
                 "time": int(time.time()),
-                "waiting": self.spider.all_spider_controller_is_waiting(),
-                'distribute_done': self.spider.all_distribute_thread_is_done()
+                "waiting": self.spider.all_spider_controller_is_waiting(),  # 任务处理完毕
+                'distribute_done': self.spider.all_distribute_thread_is_done(),  # 任务分发完毕
             }
 
             # 设置 redis 心跳
